% bag_set = generate_bag_set(bd_mat_list_file, common_label, max_I, shape_type)
%   shape_type = 0-4 (0 - default)
%               [none/shape_oriented/shape_nonoriented
%                   /shape_oriented_size_inv/shape_nonoriented_size_inv]
%
% bd_mat_list_file:
%   '/pro/webagents/data/Corel/CD4data/CorelCD4103000/103000/103000.mat';
%   '/pro/webagents/data/Corel/CD4data/CorelCD4103000/103000/103001.mat';
% label:   
%   {-1, 1}
%
function bag_set = generate_bag_set(bd_mat_list_file, label, max_I_user, in_shape_type)
%
% By Stuart Andrews (stu@cs.brown.edu)
% Brown University, Providence, RI
% Last modified: August 2003
%
max_I = 0;
if (nargin >= 3)
    max_I           = max_I_user;
end
shape_type = 0;
if (nargin >=4)
    shape_type      = in_shape_type;
end
% reads filelist
S                   = textread(bd_mat_list_file, '%s');
bag_set             = [];
% for each image_bd_mat in S
for i=1:size(S)
    name            = S{i};
    img             = load(S{i});
    bag             = generate_one_bag(i + max_I, label, img.bd, shape_type);
    bag_set         = [ bag_set, bag ];
end
return;
%%%%%%%%%%%%

%%%%%%%%%%%%
% instances = generate_one_bag(image_index, image_label, data, shape_type)
%   shape_type = 0-4 
%                   [none/shape_oriented/shape_nonoriented
%                   /shape_oriented_size_inv/shape_nonoriented_size_inv]
%   data      = [blobworld_img_struct]
%%%%%%%%%%%%
function instances = generate_one_bag(i, label, bd, shape_type)
instances = [];
% for each segment
for j=1:prod(size(bd));
    switch (shape_type)
    case 0,
        inst = generate_one_instance(i,j,label, ...
        [bd(j).con; ...
        bd(j).aniso; ...
        bd(j).x; ...
        bd(j).y; ...
        bd(j).AB; ...
        bd(j).B; ...
        bd(j).fourier_mean(:); ...
        bd(j).pixels; ...
        bd(j).mean_color(:); ...
        bd(j).color_hist(:)] ...
        );
    case 1,
        inst = generate_one_instance(i,j,label, ...
        [bd(j).con; ...
        bd(j).aniso; ...
        bd(j).x; ...
        bd(j).y; ...
        bd(j).shape_oriented(:); ...
        bd(j).AB; ...
        bd(j).B; ...
        bd(j).fourier_mean(:); ...
        bd(j).pixels; ...
        bd(j).mean_color(:); ...
        bd(j).color_hist(:)] ...
        );
    case 2,
        inst = generate_one_instance(i,j,label, ...
        [bd(j).con; ...
        bd(j).aniso; ...
        bd(j).x; ...
        bd(j).y; ...
        bd(j).shape_nonoriented(:); ...
        bd(j).AB; ...
        bd(j).B; ...
        bd(j).fourier_mean(:); ...
        bd(j).pixels; ...
        bd(j).mean_color(:); ...
        bd(j).color_hist(:)] ...
        );
    case 3,
        inst = generate_one_instance(i,j,label, ...
        [bd(j).con; ...
        bd(j).aniso; ...
        bd(j).x; ...
        bd(j).y; ...
        bd(j).shape_oriented_size_inv(:); ...
        bd(j).AB; ...
        bd(j).B; ...
        bd(j).fourier_mean(:); ...
        bd(j).pixels; ...
        bd(j).mean_color(:); ...
        bd(j).color_hist(:)] ...
        );
    case 4,
        inst = generate_one_instance(i,j,label, ...
        [bd(j).con; ...
        bd(j).aniso; ...
        bd(j).x; ...
        bd(j).y; ...
        bd(j).shape_nonoriented_size_inv(:); ...
        bd(j).AB; ...
        bd(j).B; ...
        bd(j).fourier_mean(:); ...
        bd(j).pixels; ...
        bd(j).mean_color(:); ...
        bd(j).color_hist(:)] ...
        );
    end

    instances    = [instances, inst];
    % instances(1:3,:)'

end
return;



